@@ -709,9 +709,17 @@ class language_learner:
             res = messagebox.askquestion("Ask",
                                "if load previous report file?")
             if res == 'yes':
+
                 self.report_filename = filedialog.askopenfilename(title = "Select file",filetypes = (("CSV Files","*.csv"),))
                 self.report_filename_htm = self.report_filename[:-3]+'htm'
 
+                self.path_csv = os.path.dirname(self.report_filename)
+                self.path_csv = self.path_csv[:-9]
+                print(self.path_csv)
+                self.report_path = self.generate_new_folder('L_report')
+                self.record_path = self.generate_new_folder('L_record')
+                self.source_path = self.generate_new_folder('L_source')
+                self.path_source = self.generate_new_folder("source")
                 df = pd.read_csv (self.report_filename)
 
                 if list(df.columns)==['problem', 'correct', 'time', 'if_read', 'audio_file','recognization','similarity'] and len(df['problem'])>0:
@@ -846,7 +854,7 @@ class language_learner:
         self.record_path = self.generate_new_folder('L_record')
         self.source_path = self.generate_new_folder('L_source')
         self.path_source = self.generate_new_folder("source")
-        
+
         self.initialize_widgets_for_start()
         self.generate_problem_list_from_database()
         self.problem_index = 0
